searchData={"items":[{"type":"module","title":"LeakCheck","doc":"","ref":"LeakCheck.html"},{"type":"function","title":"LeakCheck.query/3","doc":"Performs a query to the LeakCheck API and returns the raw JSON response as a map.\n\nOptions:\n  * :type - Search type (optional): \"auto\", \"email\", \"domain\", \"keyword\", etc.\n  * :limit - Maximum number of results (optional, max 1000)\n  * :offset - Results offset (optional, max 2500)","ref":"LeakCheck.html#query/3"},{"type":"module","title":"LeakCheck.Filter","doc":"Provides filtering functions for leak entries.\n\nThis module allows you to filter leak entries based on properties found in their `\"source\"` maps.\nIt includes functions to:\n\n  - Filter entries by the recency of their breach date (provided in `\"YYYY-MM\"` format).\n    The recency is computed by subtracting a specified number of years from the current UTC date.\n    By default, a 2-year threshold is used, but you can customize it using the `:years` option.\n\n  - Filter entries based on whether they contain a password update.\n    In this context, a `\"passwordless\"` field with a value of `0` indicates that the leak includes a\n    password update.","ref":"LeakCheck.Filter.html"},{"type":"function","title":"LeakCheck.Filter.filter_passwordless/1","doc":"Filters a list of leak entries to retain only those that include a password update.\n\nWithin each leak entry, a `\"passwordless\"` value of `0` (inside the `\"source\"` map)\nsignifies that the leak includes a password update. Any other value (or absence of the field)\nindicates that the leak does not have this characteristic.","ref":"LeakCheck.Filter.html#filter_passwordless/1"},{"type":"function","title":"Examples - LeakCheck.Filter.filter_passwordless/1","doc":"iex> # Given a list of entries, only those with a \"passwordless\" value of 0 are retained:\n    iex> LeakCheck.Filter.filter_passwordless(entries)\n    # Returns entries that have \"passwordless\" equal to 0 in their \"source\" map.","ref":"LeakCheck.Filter.html#filter_passwordless/1-examples"},{"type":"function","title":"LeakCheck.Filter.filter_recent/2","doc":"Filters a list of leak entries to include only those with a valid `\"source\"` map\ncontaining a `\"breach_date\"` (formatted as `\"YYYY-MM\"`) that is within the allowed recency.\n\nThe recency is determined by subtracting a number of years (from the current UTC date) as specified\nvia the `:years` option. If no option is provided, a default of 2 years is used.","ref":"LeakCheck.Filter.html#filter_recent/2"},{"type":"function","title":"Options - LeakCheck.Filter.filter_recent/2","doc":"- `:years` - The number of years (relative to the current UTC date) that define the allowed recency.\n    Defaults to `2`.","ref":"LeakCheck.Filter.html#filter_recent/2-options"},{"type":"function","title":"Examples - LeakCheck.Filter.filter_recent/2","doc":"iex> # Using the default threshold of 2 years:\n    iex> LeakCheck.Filter.filter_recent(entries)\n    # Returns entries filtered with a 2-year threshold\n    \n    iex> # Overriding the default threshold to 3 years:\n    iex> LeakCheck.Filter.filter_recent(entries, years: 3)\n    # Returns entries filtered with a 3-year threshold\n\nFor these examples, ensure that `entries` is a list of leak entries where each entry's `\"source\"`\nmap includes a `\"breach_date\"` in the `\"YYYY-MM\"` format.","ref":"LeakCheck.Filter.html#filter_recent/2-examples"},{"type":"extras","title":"LeakCheck","doc":"# LeakCheck\n\nAn unofficial Elixir client for the [LeakCheck.io](https://leakcheck.io) API v2. Search for leaked credentials and data breaches efficiently and securely.","ref":"readme.html"},{"type":"extras","title":"Disclaimer - LeakCheck","doc":"This is an **unofficial** client library for LeakCheck.io. It is not created, maintained, or endorsed by LeakCheck. For the official API documentation and support, please visit [LeakCheck.io](https://leakcheck.io).","ref":"readme.html#disclaimer"},{"type":"extras","title":"Attribution - LeakCheck","doc":"This client library interfaces with LeakCheck.io's API service. LeakCheck.io is a powerful data breach search engine that provides comprehensive credential monitoring services. Visit their website at [LeakCheck.io](https://leakcheck.io) for more information about their services.","ref":"readme.html#attribution"},{"type":"extras","title":"Installation - LeakCheck","doc":"Add `leak_check` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:leak_check, \"~> 0.2.0\"}\n  ]\nend\n\nAuthentication\nObtain your API key from LeakCheck account settings. The key should be passed in the \"X-API-Key\" header, which this client handles automatically.\nUsage\nBasic Query\nelixir\n\n# Automatic type detection\n{:ok, results} = LeakCheck.query(\"example@example.com\", \"your_api_key\")\n\n# With specific type\n{:ok, results} = LeakCheck.query(\"example.com\", \"your_api_key\", type: \"domain\")\n\n# With pagination\n{:ok, results} = LeakCheck.query(\"example\", \"your_api_key\",\n  type: \"keyword\",\n  limit: 100,\n  offset: 0\n)\n\nSearch Types\nType\tExample\tDescription\nauto\texample@example.com\tAutomatically detects email, username, phone number, or hash\nemail\texample@example.com\tSearch by email address\ndomain\tgmail.com\tSearch by domain name\nkeyword\texample\tSearch by keyword\nusername\texample\tSearch by username\nphone\t12063428631\tSearch by phone number\nhash\t31c5543c1734d25c7206f5fd\tSHA256 hash of lower-cased email (can be truncated to 24 chars)\nphash*\t31c5543c1734d25c7206f5fd\tSHA256 hash of password (Enterprise only)\norigin*\texample.com\tSearch by origin (Enterprise only)\npassword*\texample\tSearch by password (Enterprise only)\n*Enterprise features\nResponse Format\nSuccessful response:\nelixir\n\n{:ok, %{\n  \"success\" => true,\n  \"found\" => 1,\n  \"quota\" => 400,\n  \"result\" => [\n    %{\n      \"email\" => \"example@example.com\",\n      \"source\" => %{\n        \"name\" => \"BreachedWebsite.net\",\n        \"breach_date\" => \"2019-07\",\n        \"unverified\" => 0,\n        \"passwordless\" => 0,\n        \"compilation\" => 0\n      },\n      \"first_name\" => \"Example\",\n      \"last_name\" => \"Example\",\n      \"username\" => \"leakcheck\",\n      \"fields\" => [\"first_name\", \"last_name\", \"username\"]\n    }\n  ]\n}}\n\nEmpty response:\nelixir\n\n{:ok, %{\n  \"success\" => true,\n  \"found\" => 0,\n  \"quota\" => 400,\n  \"result\" => []\n}}\n\nError Handling\nThe client returns {:error, reason} for various error cases:\nError\tStatus Code\nMissing API Key\t401\nInvalid API Key\t400\nInvalid Type\t400\nInvalid Email\t400\nInvalid Query\t400\nInvalid Domain\t400\nToo Short Query\t400\nInvalid Characters\t400\nToo Many Requests\t429\nActive Plan Required\t403\nLimit Reached\t403\nCannot Determine Type\t422\nLimitations\n\n    Default rate limit: 3 requests per second (adjustable in settings)\n    Maximum limit per query: 1000 results\n    Maximum offset: 2500 results\n    Minimum query length: 3 characters\n```","ref":"readme.html#installation"},{"type":"extras","title":"Legal - LeakCheck","doc":"- This is an unofficial client library and is not affiliated with LeakCheck.io\n- LeakCheck is a trademark of LeakCheck.io\n- All rights to the LeakCheck API and service belong to LeakCheck.io","ref":"readme.html#legal"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}